==> goods-center-biz-1.6.0-20160902.132233-1-sources.jar: cn/com/duiba/goods/center/biz/remoteservice/pcg/RemotePCGGoodsInfoServiceImpl.java <==
/**
 * Project Name:goods-center-biz
 * File Name:RemotePCGGoodsInfoServiceImpl.java
 * Package Name:cn.com.duiba.goods.center.biz.remoteservice.pcg
 * Date:2016年6月29日下午9:40:12
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.biz.remoteservice.pcg;

import cn.com.duiba.dcommons.enums.GoodsTypeEnum;
import cn.com.duiba.goods.center.api.remoteservice.dto.PCGCategoryDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.PCGCategorySellerGoodsDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.PCGDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.PCGSellerDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.pcg.PcgDetailDto;
import cn.com.duiba.goods.center.api.remoteservice.front.RemotePCGGoodsInfoService;
import cn.com.duiba.goods.center.api.remoteservice.tool.Page;
import cn.com.duiba.goods.center.biz.bo.PCGFilterConfigBO;
import cn.com.duiba.goods.center.biz.bo.pcg.PCGUtilBO;
import cn.com.duiba.goods.center.biz.entity.*;
import cn.com.duiba.goods.center.biz.service.*;
import cn.com.duiba.goods.center.biz.service.impl.GoodsDirectionalConfigServiceImpl.DayLimitConfig;
import cn.com.duiba.goods.center.biz.util.PCGConvertUtil;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.duiba.wolf.utils.ObjectUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * ClassName:RemotePCGGoodsInfoServiceImpl <br/>
 * Date:     2016年6月29日 下午9:40:12 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see      
 */
@Service("remotePCGGoodsInfoService")
public class RemotePCGGoodsInfoServiceImpl implements RemotePCGGoodsInfoService{
    /**日志Logger*/
    private static Logger LOGER=LoggerFactory.getLogger(RemotePCGGoodsInfoServiceImpl.class);
    @Autowired
    private PlatformCouponGoodsService platformCouponGoodsService;
    @Autowired
    private PCGFilterConfigService pCGFilterConfigService;
    @Autowired
    private PCGSellerGoodsService pCGSellerGoodsService;
    @Autowired
    private PCGCategoryGoodsService pCGCategoryGoodsService;
    @Autowired
    private PCGFilterConfigBO pCGFilterConfigBO;
    @Autowired
    private GoodsContentService           goodsContentService;
    @Autowired
    private GoodsBatchService goodsBatchService;
    @Autowired
    private GoodsDirectionalConfigService goodsDirectionalConfigService;
    @Autowired
    private PCGUtilBO pcgUtilBO;
    @Autowired
    private GoodsTagsService goodsTagsService;
    @Override
    public PCGDto find(long pcgId) {
        PlatformCouponGoodsEntity pcg= platformCouponGoodsService.find(pcgId);
        if(pcg==null){
            return null;
        }
        PCGDto dto=PCGConvertUtil.convert(pcg);
        return dto;
    }
    
    @Override
    public DubboResult<PcgDetailDto> findForDetail(long pcgId, long appId) {
        try{
            PlatformCouponGoodsEntity pcg= platformCouponGoodsService.find(pcgId);
            if(pcg==null){
                return DubboResult.failResult("商品不存在");
            }
            if (goodsTagsService.containsAppTag(pcgId, appId)) {
                return DubboResult.failResult("商品不存在(2)");
            }
            GoodsContentEntity content=goodsContentService.findByGoods(GoodsTypeEnum.PLATFORM, pcgId);
            long stock=pcgUtilBO.getStockInApp(pcgId, appId);
            GoodsBatchEntity using=goodsBatchService.getUsingBatch(GoodsTypeEnum.PLATFORM, pcgId);
            
            PcgDetailDto dto=new PcgDetailDto();
            dto.setPcgId(pcgId);
            dto.setDescription(content.getContent());
            dto.setImage(pcg.getDetailImage());
            dto.setStock(stock);
            dto.setSubtitle(pcg.getSubtitle());
            dto.setTitle(pcg.getTitle());
            dto.setLimitPerConsumer(pcg.getLimitPerConsumer());
            if(using!=null){
                dto.setValidEndDate(using.getEndDay());
                dto.setValidStartDate(using.getStartDay());
            }
            DayLimitConfig config=goodsDirectionalConfigService.getDayLimit(GoodsTypeEnum.PLATFORM, pcgId, appId);
            if(config!=null){
                dto.setDayLimit(config.getDayLimit());
            }
            
            return DubboResult.successResult(dto);
        }catch(Exception e){
            LOGER.error("findForDetail error,pcgId="+pcgId+",appId="+appId,e);
            return DubboResult.failResult(e.getMessage());
        }
    }
    
    @Override
    public PCGDto findIncludeDeleted(long pcgId) {
        PlatformCouponGoodsEntity pcg= platformCouponGoodsService.findIncludeDeleted(pcgId);
        if(pcg==null){
            return null;
        }
        PCGDto dto=PCGConvertUtil.convert(pcg);
        // 查询平台券信息
        GoodsContentEntity goods = goodsContentService.findByGoods(GoodsTypeEnum.PLATFORM, pcgId);
        if(goods !=null ){
            dto.setDetail(goods.getContent());
        }
        return dto;
    }
    @Override
    public DubboResult<List<PCGCategoryDto>> findCategoryAll() {
        try{
            List<PCGCategoryDto>  PCGCategoryDtos = new ArrayList<PCGCategoryDto>();
            List<PCGCategoryEntity> categorys =  pCGCategoryGoodsService.findAll();
            ObjectUtil.convertList(categorys, PCGCategoryDtos, PCGCategoryDto.class);
            return DubboResult.successResult(PCGCategoryDtos);
        } catch (Exception e) {
            LOGER.error("findCategoryAll",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<PCGSellerDto>> findSellerAll() {
        try{
            List<PCGSellerDto> pCGSellerDtos = new ArrayList<PCGSellerDto>();
            List<PCGSellerEntity> sellers= pCGSellerGoodsService.findAll();
            ObjectUtil.convertList(sellers, pCGSellerDtos, PCGSellerDto.class);
            return DubboResult.successResult(pCGSellerDtos);
        } catch (Exception e) {
            LOGER.error("findSellerAll",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Page<PCGCategorySellerGoodsDto>> findCategoryGoods(long appId,long categoryId,Long consumerId,Long consumerCredits, Integer pageIndex, Integer pageSize) {
        try{
            Page<PCGCategorySellerGoodsDto> page = pCGFilterConfigBO.findCategoryGoods(appId,categoryId, consumerId, consumerCredits,  pageIndex, pageSize);
            return DubboResult.successResult(page);
        } catch (Exception e) {
            LOGER.error("findCategoryGoods appId="+appId+",consumerId="+consumerId+",consumerCredits="+consumerCredits+",pageIndex="+pageIndex+",pageSize="+pageSize,e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Page<PCGCategorySellerGoodsDto>> findSellerGoods(long appId,long sellerId,Long consumerId,Long consumerCredits, Integer pageIndex, Integer pageSize) {
        try{
            Page<PCGCategorySellerGoodsDto> page = pCGFilterConfigBO.findSellerGoods(appId,sellerId, consumerId, consumerCredits, pageIndex, pageSize);
            return DubboResult.successResult(page);
        } catch (Exception e) {
            LOGER.error("findSellerGoods appId="+appId+",consumerId="+consumerId+",consumerCredits="+consumerCredits+",pageIndex="+pageIndex+",pageSize="+pageSize,e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<Long>> findPCGFilterTargetIds(Long appId,Integer type) {
        try{
            List<Long> list = pCGFilterConfigService.selectPCGFilterTargetIds(appId, type);
            return DubboResult.successResult(list);
        }catch(Exception e){
            LOGER.error("findPCGFilterTargetIds appId="+appId+",type="+type,e);
            return DubboResult.failResult(e.getMessage());
        }
    }
    @Override
    public DubboResult<PCGCategorySellerGoodsDto> findSellerGoodsInfo(long appId, long gid, Long consumerId, Long consumerCredits) {
        try{
            PCGCategorySellerGoodsDto dto = pCGFilterConfigService.findSellerGoodsInfo(appId,gid,consumerId,consumerCredits);
            return DubboResult.successResult(dto);
        }catch(Exception e){
            LOGER.error("findGoodsCouponInfo gid="+gid,e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<PCGCategorySellerGoodsDto>> findPCGCategoryGoodsList(Long appId, Integer size) {
        return null;
    }
}

==> goods-center-biz-1.6.7.6-20161019.054736-1-sources.jar: cn/com/duiba/goods/center/biz/remoteservice/pcg/RemotePCGGoodsInfoServiceImpl.java <==
/**
 * Project Name:goods-center-biz
 * File Name:RemotePCGGoodsInfoServiceImpl.java
 * Package Name:cn.com.duiba.goods.center.biz.remoteservice.pcg
 * Date:2016年6月29日下午9:40:12
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.biz.remoteservice.pcg;

import cn.com.duiba.dcommons.enums.GoodsTypeEnum;
import cn.com.duiba.goods.center.api.remoteservice.dto.*;
import cn.com.duiba.goods.center.api.remoteservice.dto.pcg.PcgDetailDto;
import cn.com.duiba.goods.center.api.remoteservice.front.RemotePCGGoodsInfoService;
import cn.com.duiba.goods.center.api.remoteservice.tool.Page;
import cn.com.duiba.goods.center.biz.bo.PCGFilterConfigBO;
import cn.com.duiba.goods.center.biz.bo.pcg.PCGUtilBO;
import cn.com.duiba.goods.center.biz.entity.*;
import cn.com.duiba.goods.center.biz.service.*;
import cn.com.duiba.goods.center.biz.service.impl.GoodsDirectionalConfigServiceImpl.DayLimitConfig;
import cn.com.duiba.goods.center.biz.util.PCGConvertUtil;
import cn.com.duiba.wolf.dubbo.DubboResult;
import cn.com.duiba.wolf.utils.ObjectUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * ClassName:RemotePCGGoodsInfoServiceImpl <br/>
 * Date:     2016年6月29日 下午9:40:12 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see      
 */
@Service("remotePCGGoodsInfoService")
public class RemotePCGGoodsInfoServiceImpl implements RemotePCGGoodsInfoService{
    /**日志Logger*/
    private static Logger LOGER=LoggerFactory.getLogger(RemotePCGGoodsInfoServiceImpl.class);
    @Autowired
    private PlatformCouponGoodsService platformCouponGoodsService;
    @Autowired
    private PCGFilterConfigService pCGFilterConfigService;
    @Autowired
    private PCGSellerGoodsService pCGSellerGoodsService;
    @Autowired
    private PCGCategoryGoodsService pCGCategoryGoodsService;
    @Autowired
    private PCGFilterConfigBO pCGFilterConfigBO;
    @Autowired
    private GoodsContentService           goodsContentService;
    @Autowired
    private GoodsBatchService goodsBatchService;
    @Autowired
    private GoodsDirectionalConfigService goodsDirectionalConfigService;
    @Autowired
    private PCGUtilBO pcgUtilBO;
    @Autowired
    private GoodsTagsService goodsTagsService;
    @Override
    public PCGDto find(long pcgId) {
        PlatformCouponGoodsEntity pcg= platformCouponGoodsService.find(pcgId);
        if(pcg==null){
            return null;
        }
        PCGDto dto=PCGConvertUtil.convert(pcg);
        return dto;
    }
    
    @Override
    public DubboResult<PcgDetailDto> findForDetail(long pcgId, long appId) {
        try{
            PlatformCouponGoodsEntity pcg= platformCouponGoodsService.find(pcgId);
            if(pcg==null){
                return DubboResult.failResult("商品不存在");
            }
            if (goodsTagsService.containsAppTag(pcgId, appId)) {
                return DubboResult.failResult("商品不存在(2)");
            }
            GoodsContentEntity content=goodsContentService.findByGoods(GoodsTypeEnum.PLATFORM, pcgId);
            long stock=pcgUtilBO.getStockInApp(pcgId, appId);
            GoodsBatchEntity using=goodsBatchService.getUsingBatch(GoodsTypeEnum.PLATFORM, pcgId);
            
            PcgDetailDto dto=new PcgDetailDto();
            dto.setPcgId(pcgId);
            dto.setDescription(content.getContent());
            dto.setImage(pcg.getDetailImage());
            dto.setStock(stock);
            dto.setSubtitle(pcg.getSubtitle());
            dto.setTitle(pcg.getTitle());
            dto.setLimitPerConsumer(pcg.getLimitPerConsumer());
            if(using!=null){
                dto.setValidEndDate(using.getEndDay());
                dto.setValidStartDate(using.getStartDay());
            }
            DayLimitConfig config=goodsDirectionalConfigService.getDayLimit(GoodsTypeEnum.PLATFORM, pcgId, appId);
            if(config!=null){
                dto.setDayLimit(config.getDayLimit());
            }
            
            return DubboResult.successResult(dto);
        }catch(Exception e){
            LOGER.error("findForDetail error,pcgId="+pcgId+",appId="+appId,e);
            return DubboResult.failResult(e.getMessage());
        }
    }
    
    @Override
    public PCGDto findIncludeDeleted(long pcgId) {
        PlatformCouponGoodsEntity pcg= platformCouponGoodsService.findIncludeDeleted(pcgId);
        if(pcg==null){
            return null;
        }
        PCGDto dto=PCGConvertUtil.convert(pcg);
        // 查询平台券信息
        GoodsContentEntity goods = goodsContentService.findByGoods(GoodsTypeEnum.PLATFORM, pcgId);
        if(goods !=null ){
            dto.setDetail(goods.getContent());
        }
        return dto;
    }
    @Override
    public DubboResult<List<PCGCategoryDto>> findCategoryAll() {
        try{
            List<PCGCategoryDto>  PCGCategoryDtos = new ArrayList<PCGCategoryDto>();
            List<PCGCategoryEntity> categorys =  pCGCategoryGoodsService.findAll();
            ObjectUtil.convertList(categorys, PCGCategoryDtos, PCGCategoryDto.class);
            return DubboResult.successResult(PCGCategoryDtos);
        } catch (Exception e) {
            LOGER.error("findCategoryAll",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<PCGSellerDto>> findSellerAll() {
        try{
            List<PCGSellerDto> pCGSellerDtos = new ArrayList<PCGSellerDto>();
            List<PCGSellerEntity> sellers= pCGSellerGoodsService.findAll();
            ObjectUtil.convertList(sellers, pCGSellerDtos, PCGSellerDto.class);
            return DubboResult.successResult(pCGSellerDtos);
        } catch (Exception e) {
            LOGER.error("findSellerAll",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Page<PCGCategorySellerGoodsDto>> findCategoryGoods(long appId,long categoryId,Long consumerId,Long consumerCredits, Integer pageIndex, Integer pageSize) {
        try{
            Page<PCGCategorySellerGoodsDto> page = pCGFilterConfigBO.findCategoryGoods(appId,categoryId, consumerId, consumerCredits,  pageIndex, pageSize);
            return DubboResult.successResult(page);
        } catch (Exception e) {
            LOGER.error("findCategoryGoods appId="+appId+",consumerId="+consumerId+",consumerCredits="+consumerCredits+",pageIndex="+pageIndex+",pageSize="+pageSize,e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Page<PCGCategorySellerGoodsDto>> findSellerGoods(long appId,long sellerId,Long consumerId,Long consumerCredits, Integer pageIndex, Integer pageSize) {
        try{
            Page<PCGCategorySellerGoodsDto> page = pCGFilterConfigBO.findSellerGoods(appId,sellerId, consumerId, consumerCredits, pageIndex, pageSize);
            return DubboResult.successResult(page);
        } catch (Exception e) {
            LOGER.error("findSellerGoods appId="+appId+",consumerId="+consumerId+",consumerCredits="+consumerCredits+",pageIndex="+pageIndex+",pageSize="+pageSize,e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<Long>> findPCGFilterTargetIds(Long appId,Integer type) {
        try{
            List<Long> list = pCGFilterConfigService.selectPCGFilterTargetIds(appId, type);
            return DubboResult.successResult(list);
        }catch(Exception e){
            LOGER.error("findPCGFilterTargetIds appId="+appId+",type="+type,e);
            return DubboResult.failResult(e.getMessage());
        }
    }
    @Override
    public DubboResult<PCGCategorySellerGoodsDto> findSellerGoodsInfo(long appId, long gid, Long consumerId, Long consumerCredits) {
        try{
            PCGCategorySellerGoodsDto dto = pCGFilterConfigService.findSellerGoodsInfo(appId,gid,consumerId,consumerCredits);
            return DubboResult.successResult(dto);
        }catch(Exception e){
            LOGER.error("findGoodsCouponInfo gid="+gid,e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    @Deprecated
    public DubboResult<List<Long>> findPcgIds4Floor(Long appId, Integer size) {
        try {
            List<PCGCategorySellerGoodsDto> categoryGoodsList = pCGFilterConfigService.selectPCGCategoryGoodsList(appId);
            List<PCGCategorySellerGoodsDto> sellerGoodsList = pCGFilterConfigService.selectPCGSellerGoodsList(appId);
            sellerGoodsList.removeAll(categoryGoodsList);
            sellerGoodsList.addAll(categoryGoodsList);
            Collections.sort(sellerGoodsList);
            sellerGoodsList.subList(0, size);
            List<Long> result = new ArrayList<>(categoryGoodsList.size());
            for (PCGCategorySellerGoodsDto it : categoryGoodsList) {
                result.add(it.getPcgId());
            }
            return DubboResult.successResult(result);
        } catch (Exception e) {
            LOGER.error("findPcgIds4Floor appId=" + appId, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<PCGFloorDto>> findPcg4Floor(List<Long> pcgIds, Long appId, Long consumerId, Long appRate, Long consumerCredits) {
        try {
            List<PCGFloorDto> result = Collections.emptyList();
            return DubboResult.successResult(result);
        } catch (Exception e) {
            LOGER.error("findPcg4Floor pcgIds=" + pcgIds, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<PCGFloorDto>> findPcg4Floor(Long appId, Integer size) {
        try {
            List<PCGFloorDto> result = pCGFilterConfigBO.findPcgByAppId(appId,size);
            return DubboResult.successResult(result);
        } catch (Exception e) {
            LOGER.error("findPcg4Floor appId=" + appId, e);
            return DubboResult.failResult(e.getMessage());
        }
    }
}
